#!/bin/sh

INSTPREFIX="/opt/cisco/anyconnect"
BINDIR="${INSTPREFIX}/bin"
PLUGINSDIR="${BINDIR}/plugins"
LIBDIR="${INSTPREFIX}/lib"
PROFILESDIR="${INSTPREFIX}/umbrella"
ACMANIFESTDAT="${INSTPREFIX}/VPNManifest.dat"
OPENDNSMANIFEST="ACManifestUmbrella.xml"
UNINSTALLLOG="/tmp/umbrella-uninstall.log"

ANYCONNECT_OPENDNS_PACKAGE_ID=com.cisco.pkg.anyconnect.umbrella

# Array of files to remove
FILELIST=("${INSTPREFIX}/${OPENDNSMANIFEST}" \
          "${BINDIR}/acumbrellaagent" \
          "${BINDIR}/acumbrellainstallhelper" \
          "${BINDIR}/umbrella_uninstall.sh" \
          "${INSTPREFIX}/libacumbrellaplugin.dylib" \
          "${INSTPREFIX}/libacumbrellaapi.dylib" \
          "${INSTPREFIX}/libacumbrellactrl.dylib" \
          "${BINDIR}/dnscrypt-proxy" \
          "${BINDIR}/acumbrellacore" \
          "${BINDIR}/UmbrellaDiagnostic.app" \
          "${LIBDIR}/libacumbrella.dylib" \
          "${LIBDIR}/libldns.1.dylib" \
          "${LIBDIR}/libdcplugin_erc.so")

echo "Uninstalling Cisco AnyConnect Umbrella Roaming Security Module..."
echo "Uninstalling Cisco AnyConnect Umbrella Roaming Security Module..." > ${UNINSTALLLOG}
echo `whoami` "invoked $0 from " `pwd` " at " `date` >> ${UNINSTALLLOG}

# Check for root privileges
if [ `whoami` != "root" ]; then
  echo "Sorry, you need super user privileges to run this script."
  echo "Sorry, you need super user privileges to run this script." >> ${UNINSTALLLOG}
  exit 1
fi

# Post uninstall notification. 
echo "Posting uninstall notification" >> ${UNINSTALLLOG}
${BINDIR}/acumbrellainstallhelper phoneHomeOnUninstall >> ${UNINSTALLLOG} 2>&1

# update the VPNManifest.dat; if no entries remain in the .dat file then
# this tool will delete the file - DO NOT blindly delete VPNManifest.dat by
# adding it to the FILELIST above - allow this tool to delete the file if needed
if [ -f "${BINDIR}/manifesttool" ]; then
  echo "${BINDIR}/manifesttool -x ${INSTPREFIX} ${INSTPREFIX}/${OPENDNSMANIFEST}" >> ${UNINSTALLLOG}
  ${BINDIR}/manifesttool -x ${INSTPREFIX} ${INSTPREFIX}/${OPENDNSMANIFEST}
fi

# check the existence of the manifest file - if it does not exist, remove the manifesttool
if [ ! -f ${ACMANIFESTDAT} ] && [ -f ${BINDIR}/manifesttool ]; then
  echo "Removing ${BINDIR}/manifesttool" >> ${UNINSTALLLOG}
  rm -f ${BINDIR}/manifesttool
fi


# move the plugins to a different folder to stop the umbrella agent and then remove
# these plugins once umbrella agent is stopped. 
echo "Moving plugins from ${PLUGINSDIR}" >> ${UNINSTALLLOG}
echo "mv -f ${PLUGINSDIR}/libacumbrellaplugin.dylib ${INSTPREFIX}" >> ${UNINSTALLLOG}
mv -f ${PLUGINSDIR}/libacumbrellaplugin.dylib ${INSTPREFIX} 2>&1 >/dev/null
echo "mv -f ${PLUGINSDIR}/libacumbrellaapi.dylib ${INSTPREFIX}" >> ${UNINSTALLLOG}
mv -f ${PLUGINSDIR}/libacumbrellaapi.dylib ${INSTPREFIX} 2>&1 >/dev/null
echo "mv -f ${PLUGINSDIR}/libacumbrellactrl.dylib ${INSTPREFIX}" >> ${UNINSTALLLOG}
mv -f ${PLUGINSDIR}/libacumbrellactrl.dylib ${INSTPREFIX} 2>&1 >/dev/null


# wait for 2 seconds for the umbrellaagent to exit
sleep 2

# ensure that the umbrella agent is not running
OPENDNSPROC=`ps -A -o pid,command | grep '(${BINDIR}/acumbrellaagent)' | egrep -v 'grep|umbrella_uninstall' | awk '{print $1}'`
if [ ! "x${OPENDNSPROC}" = "x" ] ; then
    echo Killing `ps -A -o pid,command -p ${OPENDNSPROC} | grep ${OPENDNSPROC} | egrep -v 'ps|grep'` >> ${UNINSTALLLOG}
    kill -TERM ${OPENDNSPROC} >> ${UNINSTALLLOG} 2>&1
fi

# Remove the shared libraries only if nvm is not installed
LS_NVMAGENT=`ls /opt/cisco/anyconnect/bin/acnvmagent 2>&1>/dev/null`
RETCODE=$?
if [ ${RETCODE} != 0 ]; then
  INDEX=0
  while [ $INDEX -lt ${#SHAREDFILELIST[@]} ]; do
    echo "rm -rf "${SHAREDFILELIST[${INDEX}]}"" >> ${UNINSTALLLOG}
    rm -rf "${SHAREDFILELIST[${INDEX}]}"
    let "INDEX = $INDEX + 1"
  done
fi

# Remove only those files that we know we installed
INDEX=0
while [ $INDEX -lt ${#FILELIST[@]} ]; do
  echo "rm -rf "${FILELIST[${INDEX}]}"" >> ${UNINSTALLLOG}
  rm -rf "${FILELIST[${INDEX}]}"
  let "INDEX = $INDEX + 1"
done

# Remove the plugins directory if it is empty
if [ -d ${PLUGINSDIR} ]; then
  if [ ! -z `find "${PLUGINSDIR}" -prune -empty` ] ; then
    echo "rm -df "${PLUGINSDIR}"" >> ${UNINSTALLLOG}
    rm -df "${PLUGINSDIR}" >> ${UNINSTALLLOG} 2>&1
  fi	
fi

# Remove the bin directory if it is empty
if [ -d ${BINDIR} ]; then
  if [ ! -z `find "${BINDIR}" -prune -empty` ] ; then
    echo "rm -df "${BINDIR}"" >> ${UNINSTALLLOG}
    rm -df "${BINDIR}" >> ${UNINSTALLLOG} 2>&1
  fi	
fi

# Remove the bin directory if it is empty
if [ -d ${LIBDIR} ]; then
  if [ ! -z `find "${LIBDIR}" -prune -empty` ] ; then
    echo "rm -df "${LIBDIR}"" >> ${UNINSTALLLOG}
    rm -df "${LIBDIR}" >> ${UNINSTALLLOG} 2>&1
  fi
fi

# Remove the profiles directory
# During an upgrade, the profiles will be moved and restored by
# preupgrade and postupgrade scripts.

if [ -d ${PROFILESDIR} ]; then
    echo "rm -rf "${PROFILESDIR}"" >> ${UNINSTALLLOG}
    rm -rf "${PROFILESDIR}" >> ${UNINSTALLLOG} 2>&1
fi

# remove installer receipt
pkgutil --forget ${ANYCONNECT_OPENDNS_PACKAGE_ID} >> ${UNINSTALLLOG} 2>&1

echo "Successfully removed Cisco AnyConnect Umbrella Roaming Security Module from the system." >> ${UNINSTALLLOG}
echo "Successfully removed Cisco AnyConnect Umbrella Roaming Security Module from the system."

exit 0
